Method: Kernel#debugger

Defined in:
lib/ruby-debug.rb,
lib/ruby-debug-base.rb

#debugger(steps = 1, &block) ⇒ Object Also known as: breakpoint

If a block is given (and the debugger hasn’t been started, we run the block under the debugger. Alas, when a block is given, we can’t support running the startup script or support the steps option. FIXME.



167
168
169
170
171
172
173
174
175
# File 'lib/ruby-debug.rb', line 167

def debugger(steps = 1)
  Debugger.start
  Debugger.run_init_script(StringIO.new)
  if 0 == steps
    Debugger.current_context.stop_frame = 0
  else
    Debugger.current_context.stop_next = steps
  end
end